A data frame containing an example re-grouping structure for the afsis
reference library, which results in a slightly coarser description of clay
minerals and Fe/Ti-(hydr)oxides in powdRfps or powdRafps objects
when used with regroup().
afsis_regroupA data frame with three columns:
the phase IDs present in afsis$phases$phase_id
The phase names that constitute the first regrouping structure.
The phase names that constitute the second regrouping structure